@@ -1,6 +1,7 @@
 from flask import request, g, current_app
 from werkzeug.exceptions import Unauthorized
 from jwt import DecodeError
+from jsonclasses.exceptions import ObjectNotFoundException
 from .decode_jwt_token import decode_jwt_token
 
 
@@ -14,4 +15,6 @@ async def set_operator():
         decoded = decode_jwt_token(token)
     except DecodeError:
         raise Unauthorized('Authorization token is invalid.')
+    except ObjectNotFoundException:
+        raise Unauthorized('User is not authorized.')
     g.operator = decoded
